@@ -14,6 +14,7 @@ __email__ = "rashtrapathy.c@iotium.io"
 
 from iotiumlib.requires.Exceptions import *
 from iotiumlib.requires.utils import *
+from . import constants
 
 
 class resourcePaylod(object):
@@ -184,6 +185,28 @@ class resourcePaylod(object):
             def vlan_support(self, flag):
                 self._vlan_support = flag
 
+    class HwMonitoring(object):
+        def __init__(self, payload):
+            scanInterval_Obj = resourcePaylod.HwMonitoring.scanInterval()
+
+            if 'scan_interval' in payload and payload['scan_interval']:
+                setattr(scanInterval_Obj, 'scan_interval', payload['scan_interval'])
+                self.scan_interval = getattr(scanInterval_Obj, 'scan_interval')
+            else:
+                pass
+
+        class scanInterval(object):
+            def __init__(self):
+                self._scan_interval = constants.default_hwmonitoring_scan_interval
+
+            @property
+            def scan_interval(self):
+                return self._scan_interval
+
+            @scan_interval.setter
+            def scan_interval(self, scan_interval):
+                self._scan_interval = scan_interval
+
     class iNode(object):
 
         def __init__(self, payload):
